@@ -293,7 +293,7 @@ function select(index, ...) end
 ---
 ---[查看文档](command:extension.lua.doc?["en-us/54/manual.html/pdf-setfenv"])
 ---
----@param f     async fun(...):...|integer
+---@param f     (async fun(...):...)|integer
 ---@param table table
 ---@return function
 function setfenv(f, table) end
@@ -326,7 +326,8 @@ function setfenv(f, table) end
 ---@field __index table|(fun(t,k):any)|nil
 ---@field __newindex table|fun(t,k,v)|nil
 ---@field __call (fun(t,...):...)|nil
----@field __pairs (fun(t):(fun(t,k,v):any,any))|nil
+---@field __pairs (fun(t):((fun(t,k,v):any,any),any,any))|nil
+---@field __close (fun(t,errobj):any)|nil
 
 ---
 ---给指定表设置元表。 （你不能在 Lua 中改变其它类型值的元表，那些只能在 C 里做。） 如果 `metatable` 是 `nil`， 将指定表的元表移除。 如果原来那张元表有 `"__metatable"` 域，抛出一个错误。
@@ -434,3 +435,10 @@ function xpcall(f, msgh, arg1, ...) end
 ---@return T   ...
 ---@nodiscard
 function unpack(list, i, j) end
+
+---@version 5.1
+---@generic T1, T2, T3, T4, T5, T6, T7, T8, T9
+---@param list {[1]: T1, [2]: T2, [3]: T3, [4]: T4, [5]: T5, [6]: T6, [7]: T7, [8]: T8, [9]: T9 }
+---@return T1, T2, T3, T4, T5, T6, T7, T8, T9
+---@nodiscard
+function unpack(list) end
